ImageGridView class

Inheritance
Available extensions

Constructors

ImageGridView(IndexedWidgetBuilder itemBuilder, int itemCount, {bool? sliver, Widget? clearIcon, int? maxItemCount, WidgetBuilder? addItemBuilder, int? crossAxisCount, double? mainAxisSpacing, double? crossAxisSpacing, VoidCallback? onTapAdd, dynamic onTapDel(int)?})

Properties

addItemBuilder WidgetBuilder?
final
clearIcon Widget?
final
crossAxisCount int?
final
crossAxisSpacing double?
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder IndexedWidgetBuilder
final
itemCount int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisSpacing double?
final
maxItemCount int?
final
onTapAdd VoidCallback?
final
onTapDel → dynamic Function(int)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliver bool?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ImageGridViewState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
extAlpha(double opacity) Opacity

Available on Widget, provided by the WidgetExt extension

extCenter({double? width = double.infinity, double? height = double.infinity}) Center

Available on Widget, provided by the WidgetExt extension

extCircular(double radius) ClipRRect

Available on Widget, provided by the WidgetExt extension

extContainer({double? width = double.infinity, double? height = double.infinity, Decoration? decoration}) Container

Available on Widget, provided by the WidgetExt extension

extExpanded({int flex = 1}) Expanded

Available on Widget, provided by the WidgetExt extension

extMargin(EdgeInsetsGeometry margin) Container

Available on Widget, provided by the WidgetExt extension

extPadding(EdgeInsetsGeometry padding) Padding

Available on Widget, provided by the WidgetExt extension

extPositioned({double? left, double? top, double? right, double? bottom}) Positioned

Available on Widget, provided by the WidgetExt extension

extSingleScrollView({Axis scrollDirection = Axis.vertical}) SingleChildScrollView

Available on Widget, provided by the WidgetExt extension

extSize(double width, double height) SizedBox

Available on Widget, provided by the WidgetExt extension

extSliverAdapter({Key? key}) SliverToBoxAdapter

Available on Widget, provided by the WidgetExt extension

extVisible(Visible visible) Widget

Available on Widget, provided by the WidgetExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLongPress(VoidCallback onLongPress) InkWell

Available on Widget, provided by the WidgetExt extension

onTap(VoidCallback onTap, {int? interval, bool? releaseFocus = true}) InkWell

Available on Widget, provided by the WidgetExt extension

默认有效点击间隔一秒,interval=0 时无间隔时间
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited