Sku class
zeroStockSelectEnable 库存为0时,tag是否可选
- Inheritance
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onSelected → void Function(ISkuBean? sku)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skuBeanList
→ List<
ISkuBean> -
final
- zeroStockSelectEnable → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _SkuState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
extAlpha(
double opacity) → Opacity -
extCenter(
{double? width = double.infinity, double? height = double.infinity}) → Center -
extCircular(
double radius) → ClipRRect -
extContainer(
{double? width = double.infinity, double? height = double.infinity, Decoration? decoration}) → Container -
extExpanded(
{int flex = 1}) → Expanded -
extMargin(
EdgeInsetsGeometry margin) → Container -
extPadding(
EdgeInsetsGeometry padding) → Padding -
extPositioned(
{double? left, double? top, double? right, double? bottom}) → Positioned -
extSingleScrollView(
{Axis scrollDirection = Axis.vertical}) → SingleChildScrollView -
extSize(
double width, double height) → SizedBox -
extSliverAdapter(
{Key? key}) → SliverToBoxAdapter -
extVisible(
Visible visible) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onLongPress(
VoidCallback onLongPress) → InkWell -
onTap(
VoidCallback onTap, {int? interval, bool? releaseFocus = true}) → InkWell - 默认有效点击间隔一秒,interval=0 时无间隔时间
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited